canonical_structure

Function canonical_structure 

pub fn canonical_structure(structure: &Structure) -> Structure
The canonical form of a structure: the lexicographically least relabeling, minimized over all sort-respecting point bijections (brute force over the touched points of each sort — bounded by the degree, so a handful of points). This is the scale-independent orbit-type name.